recordStore.SimpleRecordStore

|  | ## Cheshire3 Object Model: Class SimpleRecordStore

Module recordStore :: Class SimpleRecordStore

## Class SimpleRecordStore
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                  ObjectStore --+
                                |
          baseObjects.RecordStore --+
                                    |
                                   SimpleRecordStore

Known Subclasses:
  BdbRecordStore, postgres.PostgresRecordStore, ParsingRecordStore, RemoteSlaveRecordStore

Instance Methods

__init__(self, session, node, parent) The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object.
create_record(self, session, record=None) Create a record and assign it a new identifier.
replace_record(self, session, record) Permissions checking hook for store_record if the record does not already exist.
store_record(self, session, record) Store an existing record.
fetch_record(self, session, id, parser=None) Return the record with the given identifier.
delete_record(self, session, id) Delete the record with the given identifier from storage.
fetch_recordSize(self, session, id) Return the size of the record, according to its metadata.
fetch_recordChecksum(self, session, id, parser=None) Return a checksum for the record, if one is available.
process_data(self, session, id, data, parser=None)
Inherited from `baseObjects.ObjectStore`: `create_object`, `delete_object`, `fetch_object`, `store_object` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

inTransformer |
outParser |
idNormalizer |
Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, node, parent) (Constructor) | source code
The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object. Overrides: configParser.C3Object.__init__ (inherited documentation)

### create_record(self, session, record=None) | source code
Create a record and assign it a new identifier. Overrides: baseObjects.RecordStore.create_record (inherited documentation)

### replace_record(self, session, record) | source code
Permissions checking hook for store_record if the record does not already exist. Overrides: baseObjects.RecordStore.replace_record (inherited documentation)

### store_record(self, session, record) | source code
Store an existing record. It must already have an identifier assigned to it. Overrides: baseObjects.RecordStore.store_record (inherited documentation)

### fetch_record(self, session, id, parser=None) | source code
Return the record with the given identifier. Overrides: baseObjects.RecordStore.fetch_record (inherited documentation)

### delete_record(self, session, id) | source code
Delete the record with the given identifier from storage. Overrides: baseObjects.RecordStore.delete_record (inherited documentation)

### fetch_recordSize(self, session, id) | source code
Return the size of the record, according to its metadata. Overrides: baseObjects.RecordStore.fetch_recordSize (inherited documentation)

### fetch_recordChecksum(self, session, id, parser=None) | source code
Return a checksum for the record, if one is available. Overrides: baseObjects.RecordStore.fetch_recordChecksum (inherited documentation)

### process_data(self, session, id, data, parser=None) | source code

Class Variable Details

    ### inTransformer Value:
        None

    ### outParser Value:
        None

    ### idNormalizer Value:
        None